@@ -30,7 +30,9 @@
 #include "gtkbindings.h"
 #include "gtkmarshalers.h"
 #include "gtkscrolledwindow.h"
+#include "gtkprivate.h"
 #include "gtkintl.h"
+#include "gtkalias.h"
 
 
 /* scrolled window policy and size requisition handling:
@@ -237,56 +239,56 @@ gtk_scrolled_window_class_init (GtkScrolledWindowClass *class)
 							P_("Horizontal Adjustment"),
 							P_("The GtkAdjustment for the horizontal position"),
 							GTK_TYPE_ADJUSTMENT,
-							G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+							GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT));
   g_object_class_install_property (gobject_class,
 				   PROP_VADJUSTMENT,
 				   g_param_spec_object ("vadjustment",
 							P_("Vertical Adjustment"),
 							P_("The GtkAdjustment for the vertical position"),
 							GTK_TYPE_ADJUSTMENT,
-							G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+							GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT));
   g_object_class_install_property (gobject_class,
                                    PROP_HSCROLLBAR_POLICY,
-                                   g_param_spec_enum ("hscrollbar_policy",
+                                   g_param_spec_enum ("hscrollbar-policy",
                                                       P_("Horizontal Scrollbar Policy"),
                                                       P_("When the horizontal scrollbar is displayed"),
 						      GTK_TYPE_POLICY_TYPE,
 						      GTK_POLICY_ALWAYS,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READABLE | GTK_PARAM_WRITABLE));
   g_object_class_install_property (gobject_class,
                                    PROP_VSCROLLBAR_POLICY,
-                                   g_param_spec_enum ("vscrollbar_policy",
+                                   g_param_spec_enum ("vscrollbar-policy",
                                                       P_("Vertical Scrollbar Policy"),
                                                       P_("When the vertical scrollbar is displayed"),
 						      GTK_TYPE_POLICY_TYPE,
 						      GTK_POLICY_ALWAYS,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READABLE | GTK_PARAM_WRITABLE));
 
   g_object_class_install_property (gobject_class,
                                    PROP_WINDOW_PLACEMENT,
-                                   g_param_spec_enum ("window_placement",
+                                   g_param_spec_enum ("window-placement",
                                                       P_("Window Placement"),
                                                       P_("Where the contents are located with respect to the scrollbars"),
 						      GTK_TYPE_CORNER_TYPE,
 						      GTK_CORNER_TOP_LEFT,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READABLE | GTK_PARAM_WRITABLE));
   g_object_class_install_property (gobject_class,
                                    PROP_SHADOW_TYPE,
-                                   g_param_spec_enum ("shadow_type",
+                                   g_param_spec_enum ("shadow-type",
                                                       P_("Shadow Type"),
                                                       P_("Style of bevel around the contents"),
 						      GTK_TYPE_SHADOW_TYPE,
 						      GTK_SHADOW_NONE,
-                                                      G_PARAM_READABLE | G_PARAM_WRITABLE));
+                                                      GTK_PARAM_READABLE | GTK_PARAM_WRITABLE));
 
   gtk_widget_class_install_style_property (widget_class,
-					   g_param_spec_int ("scrollbar_spacing",
+					   g_param_spec_int ("scrollbar-spacing",
 							     P_("Scrollbar spacing"),
 							     P_("Number of pixels between the scrollbars and the scrolled window"),
 							     0,
 							     G_MAXINT,
 							     DEFAULT_SCROLLBAR_SPACING,
-							     G_PARAM_READABLE));
+							     GTK_PARAM_READABLE));
 
   signals[SCROLL_CHILD] =
     g_signal_new ("scroll_child",
@@ -493,6 +495,44 @@ gtk_scrolled_window_get_vadjustment (GtkScrolledWindow *scrolled_window)
 	  NULL);
 }
 
+/**
+ * gtk_scrolled_window_get_hscrollbar:
+ * @scrolled_window: a #GtkScrolledWindow
+ * 
+ * Returns the horizontal scrollbar of @scrolled_window.
+ *
+ * Returns: the horizontal scrollbar of the scrolled window, or 
+ *  %NULL if it does not have one.
+ *
+ * Since: 2.8
+ */
+GtkWidget*
+gtk_scrolled_window_get_hscrollbar (GtkScrolledWindow *scrolled_window)
+{
+  g_return_val_if_fail (GTK_IS_SCROLLED_WINDOW (scrolled_window), NULL);
+  
+  return scrolled_window->hscrollbar;
+}
+
+/**
+ * gtk_scrolled_window_get_vscrollbar:
+ * @scrolled_window: a #GtkScrolledWindow
+ * 
+ * Returns the vertical scrollbar of @scrolled_window.
+ *
+ * Returns: the vertical scrollbar of the scrolled window, or
+ *  %NULL if it does not have one.
+ *
+ * Since: 2.8
+ */
+GtkWidget*
+gtk_scrolled_window_get_vscrollbar (GtkScrolledWindow *scrolled_window)
+{
+  g_return_val_if_fail (GTK_IS_SCROLLED_WINDOW (scrolled_window), NULL);
+
+  return scrolled_window->vscrollbar;
+}
+
 void
 gtk_scrolled_window_set_policy (GtkScrolledWindow *scrolled_window,
 				GtkPolicyType      hscrollbar_policy,
@@ -511,8 +551,8 @@ gtk_scrolled_window_set_policy (GtkScrolledWindow *scrolled_window,
       gtk_widget_queue_resize (GTK_WIDGET (scrolled_window));
 
       g_object_freeze_notify (object);
-      g_object_notify (object, "hscrollbar_policy");
-      g_object_notify (object, "vscrollbar_policy");
+      g_object_notify (object, "hscrollbar-policy");
+      g_object_notify (object, "vscrollbar-policy");
       g_object_thaw_notify (object);
     }
 }
@@ -551,7 +591,7 @@ gtk_scrolled_window_set_placement (GtkScrolledWindow *scrolled_window,
 
       gtk_widget_queue_resize (GTK_WIDGET (scrolled_window));
       
-      g_object_notify (G_OBJECT (scrolled_window), "window_placement");
+      g_object_notify (G_OBJECT (scrolled_window), "window-placement");
     }
 }
 
@@ -597,7 +637,7 @@ gtk_scrolled_window_set_shadow_type (GtkScrolledWindow *scrolled_window,
 
       gtk_widget_queue_resize (GTK_WIDGET (scrolled_window));
 
-      g_object_notify (G_OBJECT (scrolled_window), "shadow_type");
+      g_object_notify (G_OBJECT (scrolled_window), "shadow-type");
     }
 }
 
@@ -1411,9 +1451,12 @@ _gtk_scrolled_window_get_scrollbar_spacing (GtkScrolledWindow *scrolled_window)
       gint scrollbar_spacing;
       
       gtk_widget_style_get (GTK_WIDGET (scrolled_window),
-			    "scrollbar_spacing", &scrollbar_spacing,
+			    "scrollbar-spacing", &scrollbar_spacing,
 			    NULL);
 
       return scrollbar_spacing;
     }
 }
+
+#define __GTK_SCROLLED_WINDOW_C__
+#include "gtkaliasdef.c"
