@@ -37,6 +37,7 @@
 #include "gtkwindow.h"
 #include "gtkstyle.h"
 #include "gtktooltips.h"
+#include "gtkalias.h"
 
 
 #define DEFAULT_DELAY 500           /* Default delay in ms */
@@ -68,8 +69,8 @@ static void gtk_tooltips_unset_tip_window  (GtkTooltips *tooltips);
 static gboolean get_keyboard_mode          (GtkWidget   *widget);
 
 static GtkObjectClass *parent_class;
-static const gchar  *tooltips_data_key = "_GtkTooltipsData";
-static const gchar  *tooltips_info_key = "_GtkTooltipsInfo";
+static const gchar  tooltips_data_key[] = "_GtkTooltipsData";
+static const gchar  tooltips_info_key[] = "_GtkTooltipsInfo";
 
 GType
 gtk_tooltips_get_type (void)
@@ -380,10 +381,13 @@ gtk_tooltips_set_tip (GtkTooltips *tooltips,
 static gint
 gtk_tooltips_paint_window (GtkTooltips *tooltips)
 {
+  GtkRequisition req;
+
+  gtk_widget_size_request (tooltips->tip_window, &req);
   gtk_paint_flat_box (tooltips->tip_window->style, tooltips->tip_window->window,
 		      GTK_STATE_NORMAL, GTK_SHADOW_OUT, 
 		      NULL, GTK_WIDGET(tooltips->tip_window), "tooltip",
-		      0, 0, -1, -1);
+		      0, 0, req.width, req.height);
 
   return FALSE;
 }
@@ -478,6 +482,8 @@ gtk_tooltips_timeout (gpointer data)
       GTK_WIDGET_DRAWABLE (tooltips->active_tips_data->widget))
     gtk_tooltips_draw_tips (tooltips);
 
+  tooltips->timer_tag = 0;
+
   GDK_THREADS_LEAVE ();
 
   return FALSE;
@@ -791,3 +797,6 @@ gtk_tooltips_get_info_from_tip_window (GtkWindow    *tip_window,
 
   return has_tips;
 }
+
+#define __GTK_TOOLTIPS_C__
+#include "gtkaliasdef.c"
